#include <stdio.h>
#include <math.h>
#include <time.h>

#include "FLAME.h"

int main(int argc, char *argv[])
{
  int 
    m, n, k;

  double
    dtime,
    mflops;

  FLA_Obj
    A, B, C;
  
  /* Initialize FLAME */
  FLA_Init();

  /* Matrix dimensions */
  printf( "enter m, n, k:" );
  scanf( "%d%d%d", &m, &n, &k );
  printf( "m, n, k: %d %d %d\n", m, n, k );

  /* Allocate space for the matrices */

  FLA_Obj_create( FLA_DOUBLE, m, k, &A );
  FLA_Obj_create( FLA_DOUBLE, k, n, &B );
  FLA_Obj_create( FLA_DOUBLE, m, n, &C );

  /* Generate random matrices A, B, C */
  FLA_Random_matrix( A );
  FLA_Random_matrix( B );
  FLA_Random_matrix( C );

  /* Get a time stamp */
  dtime = dclock();

  /* Perform the matrix-matrix multiplication C = A * B + C */
  FLA_Gemm( FLA_NO_TRANSPOSE, FLA_NO_TRANSPOSE,
            FLA_ONE, A, B, FLA_ONE, C );

  /* Get elapsed time */
  dtime = dclock() - dtime;

  /* flops executed */
  mflops = 2.0 * m * n * k;  

  /* Report rate of execution */
  printf( "GFLOPS attained: %lf\n", mflops / dtime / 1.0e9 );

  FLA_Obj_free( &A );
  FLA_Obj_free( &B );
  FLA_Obj_free( &C );

  FLA_Finalize();
}

